@@ -7,7 +7,9 @@
 #include <cstdio>
 #include <memory>
 #include <string>
-
+#ifdef WIN32
+#include <windows.h>
+#endif
 #include "timing.hpp"
 
 typedef struct CPUData_ {
@@ -133,6 +135,7 @@ public:
    bool UpdateCoreMhz();
    bool UpdateCpuTemp();
    bool UpdateCpuPower();
+   bool ReadcpuTempFile(int& temp);
    bool GetCpuFile();
    bool InitCpuPowerData();
    double GetCPUPeriod() { return m_cpuPeriod; }
@@ -157,5 +160,7 @@ private:
 };
 
 extern CPUStats cpuStats;
-
+#ifdef WIN32
+uint64_t FileTimeToInt64( const FILETIME& ft );
+#endif
 #endif //MANGOHUD_CPU_H
