@@ -17,6 +17,8 @@
 #include "string_utils.h"
 #include "app/mangoapp.h"
 #include <IconsForkAwesome.h>
+#include "version.h"
+#include "blacklist.h"
 
 #define CHAR_CELSIUS    "\xe2\x84\x83"
 #define CHAR_FAHRENHEIT "\xe2\x84\x89"
@@ -25,7 +27,7 @@ using namespace std;
 
 // Cut from https://github.com/ocornut/imgui/pull/2943
 // Probably move to ImGui
-float SRGBToLinear(float in)
+static float SRGBToLinear(float in)
 {
     if (in <= 0.04045f)
         return in / 12.92f;
@@ -33,15 +35,7 @@ float SRGBToLinear(float in)
         return powf((in + 0.055f) / 1.055f, 2.4f);
 }
 
-float LinearToSRGB(float in)
-{
-    if (in <= 0.0031308f)
-        return in * 12.92f;
-    else
-        return 1.055f * powf(in, 1.0f / 2.4f) - 0.055f;
-}
-
-ImVec4 SRGBToLinear(ImVec4 col)
+static ImVec4 SRGBToLinear(ImVec4 col)
 {
     col.x = SRGBToLinear(col.x);
     col.y = SRGBToLinear(col.y);
@@ -51,16 +45,6 @@ ImVec4 SRGBToLinear(ImVec4 col)
     return col;
 }
 
-ImVec4 LinearToSRGB(ImVec4 col)
-{
-    col.x = LinearToSRGB(col.x);
-    col.y = LinearToSRGB(col.y);
-    col.z = LinearToSRGB(col.z);
-    // Alpha component is already linear
-
-    return col;
-}
-
 template<typename T, typename R = float>
 R format_units(T value, const char*& unit)
 {
@@ -125,7 +109,7 @@ void HudElements::convert_colors(bool do_conv, const struct overlay_params& para
 /**
 * Go to next column or second column on new row
 */
-void ImguiNextColumnOrNewRow(int column = -1)
+static void ImguiNextColumnOrNewRow(int column = -1)
 {
     if (column > -1 && column < ImGui::TableGetColumnCount())
         ImGui::TableSetColumnIndex(column);
@@ -137,28 +121,28 @@ void ImguiNextColumnOrNewRow(int column = -1)
     }
 }
 
-void ImGuiTableSetColumnIndex(int column)
+static void ImGuiTableSetColumnIndex(int column)
 {
     ImGui::TableSetColumnIndex(std::max(0, std::min(column, ImGui::TableGetColumnCount() - 1)));
 }
 
 void HudElements::time(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_time]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::TextColored(ImVec4(1.0f, 1.0f, 1.0f, 1.00f), "%s", HUDElements.sw_stats->time.c_str());
     }
 }
 
 void HudElements::version(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_version]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::Text("%s", MANGOHUD_VERSION);
     }
 }
 
 void HudElements::gpu_stats(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_gpu_stats]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         const char* gpu_text;
         if (HUDElements.params->gpu_text.empty())
             gpu_text = "GPU";
@@ -192,7 +176,10 @@ void HudElements::gpu_stats(){
             ImguiNextColumnOrNewRow();
             right_aligned_text(text_color, HUDElements.ralign_width, "%i", gpu_info.temp);
             ImGui::SameLine(0, 1.0f);
-            ImGui::Text("°C");
+            if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_hud_compact])
+                ImGui::Text("°");
+            else
+                ImGui::Text("°C");
         }
         if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_gpu_core_clock]){
             ImguiNextColumnOrNewRow();
@@ -219,7 +206,7 @@ void HudElements::gpu_stats(){
 
 void HudElements::cpu_stats(){
     if(HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_cpu_stats]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         const char* cpu_text;
         if (HUDElements.params->cpu_text.empty())
             cpu_text = "CPU";
@@ -254,7 +241,10 @@ void HudElements::cpu_stats(){
             ImguiNextColumnOrNewRow();
             right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%i", cpuStats.GetCPUDataTotal().temp);
             ImGui::SameLine(0, 1.0f);
-            ImGui::Text("°C");
+            if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_hud_compact])
+                ImGui::Text("°");
+            else
+                ImGui::Text("°C");
         }
 
         if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_cpu_mhz]){
@@ -285,7 +275,7 @@ void HudElements::core_load(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_core_load]){
          for (const CPUData &cpuData : cpuStats.GetCPUData())
          {
-            ImGui::TableNextRow(); ImGui::TableNextColumn();
+            ImGui::TableNextColumn();
             ImGui::TextColored(HUDElements.colors.cpu, "CPU");
             ImGui::SameLine(0, 1.0f);
             ImGui::PushFont(HUDElements.sw_stats->font1);
@@ -326,7 +316,7 @@ void HudElements::core_load(){
 void HudElements::io_stats(){
 #ifndef _WIN32
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_io_read] || HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_io_write]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_io_read] && !HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_io_write])
             ImGui::TextColored(HUDElements.colors.io, "IO RD");
         else if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_io_read] && HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_io_write])
@@ -358,7 +348,7 @@ void HudElements::io_stats(){
 
 void HudElements::vram(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_vram]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::TextColored(HUDElements.colors.vram, "VRAM");
         ImGui::TableNextColumn();
         // Add gtt_used to vram usage for APUs
@@ -386,14 +376,16 @@ void HudElements::vram(){
 void HudElements::ram(){
 #ifdef __linux__
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_ram]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::TextColored(HUDElements.colors.ram, "RAM");
         ImGui::TableNextColumn();
         right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%.1f", memused);
-        ImGui::SameLine(0,1.0f);
-        ImGui::PushFont(HUDElements.sw_stats->font1);
-        ImGui::Text("GiB");
-        ImGui::PopFont();
+        if (!HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_hud_compact]){
+            ImGui::SameLine(0,1.0f);
+            ImGui::PushFont(HUDElements.sw_stats->font1);
+            ImGui::Text("GiB");
+            ImGui::PopFont();
+        }
     }
 
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_ram] && HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_swap]){
@@ -414,7 +406,7 @@ void HudElements::procmem()
     if (!HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_procmem])
         return;
 
-    ImGui::TableNextRow(); ImGui::TableNextColumn();
+    ImGui::TableNextColumn();
     ImGui::TextColored(HUDElements.colors.ram, "PMEM");
     ImGui::TableNextColumn();
     right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%.1f", format_units(proc_mem.resident, unit));
@@ -445,8 +437,11 @@ void HudElements::procmem()
 
 void HudElements::fps(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_fps] && !HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_fps_only]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
-        ImGui::TextColored(HUDElements.colors.engine, "%s", engines[HUDElements.sw_stats->engine]);
+        ImGui::TableNextColumn();
+        if(HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_hud_compact] || HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_horizontal])
+            ImGui::TextColored(HUDElements.colors.engine, "%s", "FPS");
+        else
+            ImGui::TextColored(HUDElements.colors.engine, "%s", engines[HUDElements.sw_stats->engine]);
         ImGui::TableNextColumn();
         if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_fps_color_change]){
             int fps = int(HUDElements.sw_stats->fps);
@@ -464,9 +459,11 @@ void HudElements::fps(){
             right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%.0f", HUDElements.sw_stats->fps);
         }
         ImGui::SameLine(0, 1.0f);
-        ImGui::PushFont(HUDElements.sw_stats->font1);
-        ImGui::Text("FPS");
-        ImGui::PopFont();
+        if(!HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_hud_compact] && !HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_horizontal]){
+            ImGui::PushFont(HUDElements.sw_stats->font1);
+            ImGui::Text("FPS");
+            ImGui::PopFont();
+        }
         if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_frametime]){
             ImguiNextColumnOrNewRow();
             right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%.1f", 1000 / HUDElements.sw_stats->fps);
@@ -476,14 +473,14 @@ void HudElements::fps(){
             ImGui::PopFont();
         }
     } else if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_engine_version]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::TextColored(HUDElements.colors.engine, "%s", HUDElements.sw_stats->engineName.c_str());
     }
 }
 
 void HudElements::fps_only(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_fps_only]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         auto load_color = HUDElements.colors.text;
         if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_fps_color_change]){
             int fps = int(HUDElements.sw_stats->fps);
@@ -502,7 +499,7 @@ void HudElements::fps_only(){
 
 void HudElements::gpu_name(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_gpu_name] && !HUDElements.sw_stats->gpuName.empty()){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::PushFont(HUDElements.sw_stats->font1);
         ImGui::TextColored(HUDElements.colors.engine,
             "%s", HUDElements.sw_stats->gpuName.c_str());
@@ -512,7 +509,7 @@ void HudElements::gpu_name(){
 
 void HudElements::engine_version(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_engine_version]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::PushFont(HUDElements.sw_stats->font1);
         if (HUDElements.is_vulkan) {
             if ((HUDElements.sw_stats->engine == EngineTypes::DXVK || HUDElements.sw_stats->engine == EngineTypes::VKD3D)){
@@ -539,7 +536,7 @@ void HudElements::engine_version(){
 
 void HudElements::vulkan_driver(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_vulkan_driver] && !HUDElements.sw_stats->driverName.empty()){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::PushFont(HUDElements.sw_stats->font1);
         ImGui::TextColored(HUDElements.colors.engine,
             "%s", HUDElements.sw_stats->driverName.c_str());
@@ -549,7 +546,7 @@ void HudElements::vulkan_driver(){
 
 void HudElements::arch(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_arch]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::PushFont(HUDElements.sw_stats->font1);
         ImGui::TextColored(HUDElements.colors.engine, "%s", "" MANGOHUD_ARCH);
         ImGui::PopFont();
@@ -558,7 +555,7 @@ void HudElements::arch(){
 
 void HudElements::wine(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_wine]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         if (!wineVersion.empty()){
             ImGui::PushFont(HUDElements.sw_stats->font1);
             ImGui::TextColored(HUDElements.colors.wine, "%s", wineVersion.c_str());
@@ -569,14 +566,16 @@ void HudElements::wine(){
 
 void HudElements::frame_timing(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_frame_timing]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
-        ImGui::Dummy(ImVec2(0.0f, real_font_size.y));
+        ImGui::TableNextColumn();
         ImGui::PushFont(HUDElements.sw_stats->font1);
-        ImGui::TextColored(HUDElements.colors.engine, "%s", "Frametime");
-        ImGui::TableSetColumnIndex(ImGui::TableGetColumnCount() - 1);
-        ImGui::Dummy(ImVec2(0.0f, real_font_size.y));
-        right_aligned_text(HUDElements.colors.text, ImGui::GetContentRegionAvail().x, "min: %.1fms, max: %.1fms", min_frametime, max_frametime);
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        if (!HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_horizontal] && !HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_hud_compact]){
+            ImGui::Dummy(ImVec2(0.0f, real_font_size.y));
+            ImGui::TextColored(HUDElements.colors.engine, "%s", "Frametime");
+            ImGui::TableSetColumnIndex(ImGui::TableGetColumnCount() - 1);
+            ImGui::Dummy(ImVec2(0.0f, real_font_size.y));
+            right_aligned_text(HUDElements.colors.text, ImGui::GetContentRegionAvail().x, "min: %.1fms, max: %.1fms", min_frametime, max_frametime);
+            ImGui::TableNextColumn();
+        }
         char hash[40];
         snprintf(hash, sizeof(hash), "##%s", overlay_param_names[OVERLAY_PARAM_ENABLED_frame_timing]);
         HUDElements.sw_stats->stat_selector = OVERLAY_PLOTS_frame_timing;
@@ -584,27 +583,44 @@ void HudElements::frame_timing(){
         ImGui::PushStyleColor(ImGuiCol_FrameBg, ImVec4(0.0f, 0.0f, 0.0f, 0.0f));
         double min_time = 0.0f;
         double max_time = 50.0f;
+        float width, height = 0;
 #ifdef MANGOAPP
-        const ImVec2 sz = ImGui::CalcTextSize("1000.0ms");
-        float width = ImGui::GetWindowContentRegionWidth() - sz.x;
+        if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_horizontal] || HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_hud_compact]){
+            width = 150;
+            height = 24;
+        } else {
+            const ImVec2 sz = ImGui::CalcTextSize("1000.0ms");
+            width = ImGui::GetWindowContentRegionWidth() - sz.x;
+        }
 #else
-        float width = ImGui::GetWindowContentRegionWidth();
+        if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_horizontal]){
+            width = 150;
+            height = 24;
+        } else {
+            width = ImGui::GetWindowContentRegionWidth();
+            height = max_time;
+        }
 #endif
-        if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_histogram]){
-            ImGui::PlotHistogram(hash, get_time_stat, HUDElements.sw_stats,
+        if (ImGui::BeginChild("my_child_window", ImVec2(width, height))) {
+            if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_histogram]){
+                ImGui::PlotHistogram(hash, get_time_stat, HUDElements.sw_stats,
+                                    ARRAY_SIZE(HUDElements.sw_stats->frames_stats), 0,
+                                    NULL, min_time, max_time,
+                                    ImVec2(width, height));
+            } else {
+                ImGui::PlotLines(hash, get_time_stat, HUDElements.sw_stats,
                                 ARRAY_SIZE(HUDElements.sw_stats->frames_stats), 0,
                                 NULL, min_time, max_time,
-                                ImVec2(width, 50));
-        } else {
-            ImGui::PlotLines(hash, get_time_stat, HUDElements.sw_stats,
-                            ARRAY_SIZE(HUDElements.sw_stats->frames_stats), 0,
-                            NULL, min_time, max_time,
-                            ImVec2(width, 50));
+                                ImVec2(width, height));
+            }
         }
+        ImGui::EndChild();
 #ifdef MANGOAPP
-        ImGui::SameLine();
-        ImGuiTableSetColumnIndex(ImGui::TableGetColumnCount() - 1);
-        right_aligned_text(HUDElements.colors.text, ImGui::GetContentRegionAvail().x, "%.1fms", frametime / 1000.f);
+        if (!HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_horizontal] && !HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_hud_compact]){
+            ImGui::SameLine();
+            ImGuiTableSetColumnIndex(ImGui::TableGetColumnCount() - 1);
+            right_aligned_text(HUDElements.colors.text, ImGui::GetContentRegionAvail().x, "%.1fms", frametime / 1000.f);
+        }
 #endif
         ImGui::PopFont();
         ImGui::PopStyleColor();
@@ -616,7 +632,7 @@ void HudElements::media_player(){
     if (!HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_media_player])
         return;
 
-    ImGui::TableNextRow(); ImGui::TableNextColumn();
+    ImGui::TableNextColumn();
     uint32_t f_idx = (HUDElements.sw_stats->n_frames - 1) % ARRAY_SIZE(HUDElements.sw_stats->frames_stats);
     uint64_t frame_timing = HUDElements.sw_stats->frames_stats[f_idx].stats[OVERLAY_PLOTS_frame_timing];
     ImFont scaled_font = *HUDElements.sw_stats->font_text;
@@ -635,11 +651,11 @@ void HudElements::media_player(){
 
 void HudElements::resolution(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_resolution]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         const auto res  = ImGui::GetIO().DisplaySize;
         ImGui::PushFont(HUDElements.sw_stats->font1);
         ImGui::TextColored(HUDElements.colors.engine, "Resolution");
-        ImGuiTableSetColumnIndex(HUDElements.text_column);
+        ImGui::TableNextColumn();
         right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width * 1.3, "%.0fx%.0f", res.x, res.y);
         ImGui::PopFont();
     }
@@ -650,17 +666,18 @@ void HudElements::show_fps_limit(){
         int fps = 0;
         if (fps_limit_stats.targetFrameTime.count())
             fps = 1000000000 / fps_limit_stats.targetFrameTime.count();
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::PushFont(HUDElements.sw_stats->font1);
-        ImGui::TextColored(HUDElements.colors.engine, "%s","FPS limit");
-        ImGuiTableSetColumnIndex(HUDElements.text_column);
+        const char* method = fps_limit_stats.method == FPS_LIMIT_METHOD_EARLY ? "early" : "late";
+        ImGui::TextColored(HUDElements.colors.engine, "%s (%s)","FPS limit",method);
+        ImGui::TableNextColumn();
         right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%i", fps);
         ImGui::PopFont();
     }
 }
 
 void HudElements::custom_text_center(){
-    ImGui::TableNextRow(); ImGui::TableNextColumn();
+    ImGui::TableNextColumn();
     ImGui::PushFont(HUDElements.sw_stats->font1);
     const std::string& value = HUDElements.ordered_functions[HUDElements.place].second;
     center_text(value);
@@ -670,7 +687,7 @@ void HudElements::custom_text_center(){
 }
 
 void HudElements::custom_text(){
-    ImGui::TableNextRow(); ImGui::TableNextColumn();
+    ImGui::TableNextColumn();
     ImGui::PushFont(HUDElements.sw_stats->font1);
     const std::string& value = HUDElements.ordered_functions[HUDElements.place].second;
     ImGui::TextColored(HUDElements.colors.text, "%s",value.c_str());
@@ -690,10 +707,10 @@ void HudElements::_exec(){
 
 void HudElements::gamemode(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_gamemode]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::PushFont(HUDElements.sw_stats->font1);
         ImGui::TextColored(HUDElements.colors.engine, "%s", "GAMEMODE");
-        ImGuiTableSetColumnIndex(HUDElements.text_column);
+        ImGui::TableNextColumn();
         right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%s", HUDElements.gamemode_bol ? "ON" : "OFF");
         ImGui::PopFont();
     }
@@ -701,10 +718,10 @@ void HudElements::gamemode(){
 
 void HudElements::vkbasalt(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_vkbasalt]){
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::PushFont(HUDElements.sw_stats->font1);
         ImGui::TextColored(HUDElements.colors.engine, "%s", "VKBASALT");
-        ImGuiTableSetColumnIndex(HUDElements.text_column);
+        ImGui::TableNextColumn();
         right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%s", HUDElements.vkbasalt_bol ? "ON" : "OFF");
         ImGui::PopFont();
     }
@@ -714,8 +731,11 @@ void HudElements::battery(){
 #ifdef __linux__
     if (Battery_Stats.batt_count > 0) {
         if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_battery]) {
-            ImGui::TableNextRow(); ImGui::TableNextColumn();
-            ImGui::TextColored(HUDElements.colors.battery, "BATT");
+            ImGui::TableNextColumn();
+            if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_hud_compact])
+                ImGui::TextColored(HUDElements.colors.battery, "BAT");
+            else
+                ImGui::TextColored(HUDElements.colors.battery, "BATT");
             ImGui::TableNextColumn();
             if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_battery_icon]) {
                 switch(int(Battery_Stats.current_percent)){
@@ -739,32 +759,42 @@ void HudElements::battery(){
                 ImGui::Text("%%");
             }
             if (Battery_Stats.current_watt != 0) {
-                ImguiNextColumnOrNewRow();
-                right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%.1f", Battery_Stats.current_watt);
-                ImGui::SameLine(0,1.0f);
-                ImGui::PushFont(HUDElements.sw_stats->font1);
-                ImGui::Text("W");
-                ImGui::PopFont();
-                ImGui::TableNextRow(); ImGui::TableNextColumn();
-                float hours;
-                float minutes;
-                // float seconds;
-                minutes = std::modf(Battery_Stats.remaining_time, &hours);
-                minutes *= 60;
-                // seconds = std::modf(minutes, &minutes);
-                // seconds *= 60;
-                ImGui::PushFont(HUDElements.sw_stats->font1);
-                ImGui::TextColored(HUDElements.colors.text, "%s", "Remaining Time");
-                ImGui::PopFont();
-                ImGuiTableSetColumnIndex(2);
-                // ImGui::TextColored(HUDElements.colors.text, "%02.0f:%02.0f:%02.0f", hours, minutes, seconds);
-                right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%02.0f:%02.0f", hours, minutes);
-            }
-            else {
+                printf("%i\n", HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_battery_watt]);
+                if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_battery_watt]){
+                    ImguiNextColumnOrNewRow();
+                    right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%.1f", Battery_Stats.current_watt);
+                    ImGui::SameLine(0,1.0f);
+                    ImGui::PushFont(HUDElements.sw_stats->font1);
+                    ImGui::Text("W");
+                    ImGui::PopFont();
+                }
+                if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_battery_time]) {
+                    float hours;
+                    float minutes;
+                    minutes = std::modf(Battery_Stats.remaining_time, &hours);
+                    minutes *= 60;
+                    if (!HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_horizontal] && !HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_hud_compact]){
+                        ImGui::TableNextRow();
+                        ImGui::NextColumn();
+                        ImGui::PushFont(HUDElements.sw_stats->font1);
+                        ImGuiTableSetColumnIndex(0);
+                        ImGui::TextColored(HUDElements.colors.text, "%s", "Remaining Time");
+                        ImGui::PopFont();
+                        ImGuiTableSetColumnIndex(2);
+                    } else {
+                        if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_horizontal])
+                            ImguiNextColumnOrNewRow();
+
+                        ImguiNextColumnOrNewRow();
+                    }
+                    right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%02.0f:%02.0f", hours, minutes);
+                }
+            } else { 
                 ImguiNextColumnOrNewRow();
                 right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%s", ICON_FK_PLUG);
             }
         }
+
     }
 #endif
 }
@@ -772,7 +802,7 @@ void HudElements::battery(){
 void HudElements::gamescope_fsr(){
 #ifdef MANGOAPP
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_fsr]) {
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         string FSR_TEXT;
         ImVec4 FSR_COLOR;
         if (g_fsrUpscale){
@@ -803,7 +833,7 @@ void HudElements::gamescope_fsr(){
 void HudElements::gamescope_frame_timing(){
 #ifdef MANGOAPP
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_debug]) {
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::Dummy(ImVec2(0.0f, real_font_size.y));
         ImGui::PushFont(HUDElements.sw_stats->font1);
         ImGui::TextColored(HUDElements.colors.engine, "%s", "App");
@@ -814,7 +844,7 @@ void HudElements::gamescope_frame_timing(){
         auto max = std::max_element(gamescope_debug_app.begin(), gamescope_debug_app.end());
         right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width * 1.3, "min: %.1fms, max: %.1fms", min[0], max[0]);
         ImGui::PopFont();
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         char hash[40];
         snprintf(hash, sizeof(hash), "##%s", overlay_param_names[OVERLAY_PARAM_ENABLED_frame_timing]);
         HUDElements.sw_stats->stat_selector = OVERLAY_PLOTS_frame_timing;
@@ -833,7 +863,7 @@ void HudElements::gamescope_frame_timing(){
             ImGui::PopFont();
         ImGui::PopStyleColor();
         if (gamescope_debug_latency.back() > -1){
-            ImGui::TableNextRow(); ImGui::TableNextColumn();
+            ImGui::TableNextColumn();
             ImGui::Dummy(ImVec2(0.0f, real_font_size.y));
             ImGui::PushFont(HUDElements.sw_stats->font1);
             ImGui::TextColored(HUDElements.colors.engine, "%s", "Latency");
@@ -844,7 +874,7 @@ void HudElements::gamescope_frame_timing(){
             max = std::max_element(gamescope_debug_latency.begin(), gamescope_debug_latency.end());
             right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width * 1.3, "min: %.1fms, max: %.1fms", min[0], max[0]);
             ImGui::PopFont();
-            ImGui::TableNextRow(); ImGui::TableNextColumn();
+            ImGui::TableNextColumn();
 
             ImGui::PushStyleColor(ImGuiCol_FrameBg, ImVec4(0.0f, 0.0f, 0.0f, 0.0f));
             ImGui::PushStyleColor(ImGuiCol_PlotLines, ImVec4(0,0,1,1));
@@ -874,7 +904,7 @@ void HudElements::gamepad_battery()
                 bool report_percent = gamepad_data[i].report_percent;
                 bool charging = gamepad_data[i].is_charging;
 
-                ImGui::TableNextRow(); ImGui::TableNextColumn();
+                ImGui::TableNextColumn();
                 ImGui::PushFont(HUDElements.sw_stats->font1);
                 ImGui::TextColored(HUDElements.colors.engine, "%s", name.c_str());
                 ImGui::TableNextColumn();
@@ -918,11 +948,10 @@ void HudElements::gamepad_battery()
 
 void HudElements::frame_count(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_frame_count]){
-        ImGui::TableNextRow();
         ImGui::TableNextColumn();
         ImGui::PushFont(HUDElements.sw_stats->font1);
         ImGui::TextColored(HUDElements.colors.engine, "Frame Count");
-        ImGuiTableSetColumnIndex(HUDElements.text_column);
+        ImGui::TableNextColumn();
         right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, "%" PRIu64, HUDElements.sw_stats->n_frames);
         ImGui::PopFont();
     }
@@ -930,7 +959,7 @@ void HudElements::frame_count(){
 
 void HudElements::fan(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_fan] && fan_speed != -1) {
-        ImGui::TableNextRow(); ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
         ImGui::TextColored(HUDElements.colors.engine, "%s", "FAN");
         ImGui::TableNextColumn();
         right_aligned_text(HUDElements.colors.text,HUDElements.ralign_width, "%i", fan_speed);
@@ -944,7 +973,7 @@ void HudElements::fan(){
 void HudElements::throttling_status(){
     if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_throttling_status]){
         if (gpu_info.is_power_throttled || gpu_info.is_current_throttled || gpu_info.is_temp_throttled || gpu_info.is_other_throttled){
-            ImGui::TableNextRow(); ImGui::TableNextColumn();
+            ImGui::TableNextColumn();
             ImGui::TextColored(HUDElements.colors.engine, "%s", "Throttling");
             ImGui::TableNextColumn();
             ImGui::TableNextColumn();
@@ -961,7 +990,7 @@ void HudElements::throttling_status(){
 }
 
 void HudElements::graphs(){
-    ImGui::TableNextRow(); ImGui::TableNextColumn();
+    ImGui::TableNextColumn();
     ImGui::Dummy(ImVec2(0.0f, real_font_size.y));
     const std::string& value = HUDElements.ordered_functions[HUDElements.place].second;
     assert(kMaxGraphEntries >= graph_data.size());
@@ -1059,7 +1088,7 @@ void HudElements::graphs(){
     ImGui::PopFont();
     ImGui::Dummy(ImVec2(0.0f,5.0f));
     ImGui::PushStyleColor(ImGuiCol_FrameBg, ImVec4(0.0f, 0.0f, 0.0f, 0.0f));
-    ImGui::TableNextRow(); ImGui::TableNextColumn();
+    ImGui::TableNextColumn();
     if (!HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_histogram]){
         ImGui::PlotLines("", arr.data(),
                 arr.size(), 0,
@@ -1075,6 +1104,18 @@ void HudElements::graphs(){
     ImGui::PopStyleColor(1);
 }
 
+void HudElements::exec_name(){
+    if (HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_exec_name]){
+        ImGui::PushFont(HUDElements.sw_stats->font1);
+        ImGui::TableNextColumn();
+        ImGui::TextColored(HUDElements.colors.engine, "%s", "Executable name");
+        ImGui::TableNextColumn();
+        ImGui::TableNextColumn();
+        right_aligned_text(HUDElements.colors.text, HUDElements.ralign_width, global_proc_name.c_str());
+        ImGui::PopFont();
+    }
+}
+
 void HudElements::sort_elements(const std::pair<std::string, std::string>& option){
     const auto& param = option.first;
     const auto& value = option.second;
@@ -1117,6 +1158,7 @@ void HudElements::sort_elements(const std::pair<std::string, std::string>& optio
     if (param == "frame_count")     { ordered_functions.push_back({frame_count, value});            }
     if (param == "fan")             { ordered_functions.push_back({fan, value});                    }
     if (param == "throttling_status")        { ordered_functions.push_back({throttling_status, value});               }
+    if (param == "exec_name")        { ordered_functions.push_back({exec_name, value});               }
     if (param == "graphs"){
         if (!HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_graphs])
             HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_graphs] = true;
@@ -1136,42 +1178,72 @@ void HudElements::sort_elements(const std::pair<std::string, std::string>& optio
 void HudElements::legacy_elements(){
     string value = "NULL";
     ordered_functions.clear();
-    ordered_functions.push_back({time,               value});
-    ordered_functions.push_back({version,            value});
-    ordered_functions.push_back({gpu_stats,          value});
-    ordered_functions.push_back({cpu_stats,          value});
-    ordered_functions.push_back({core_load,          value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_time])
+        ordered_functions.push_back({time,               value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_version])
+        ordered_functions.push_back({version,            value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_gpu_stats])
+        ordered_functions.push_back({gpu_stats,          value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_cpu_stats])
+        ordered_functions.push_back({cpu_stats,          value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_core_load])
+        ordered_functions.push_back({core_load,          value});
 #ifndef MANGOAPP
-    ordered_functions.push_back({io_stats,           value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_io_stats])
+        ordered_functions.push_back({io_stats,           value});
 #endif
-    ordered_functions.push_back({vram,               value});
-    ordered_functions.push_back({ram,                value});
-    ordered_functions.push_back({battery,            value});
-    ordered_functions.push_back({fan,                value});
-    ordered_functions.push_back({gamescope_fsr,      value});
-    ordered_functions.push_back({throttling_status,  value});
-    ordered_functions.push_back({fps,                value});
-    ordered_functions.push_back({fps_only,           value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_vram])
+        ordered_functions.push_back({vram,               value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_ram])
+        ordered_functions.push_back({ram,                value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_battery])
+        ordered_functions.push_back({battery,            value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_fan])
+        ordered_functions.push_back({fan,                value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_fsr])
+        ordered_functions.push_back({gamescope_fsr,      value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_throttling_status])
+        ordered_functions.push_back({throttling_status,  value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_fps])
+        ordered_functions.push_back({fps,                value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_fps_only])
+        ordered_functions.push_back({fps_only,           value});
 #ifndef MANGOAPP
-    ordered_functions.push_back({engine_version,     value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_engine_version])
+        ordered_functions.push_back({engine_version,     value});
 #endif
-    ordered_functions.push_back({gpu_name,           value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_gpu_name])
+        ordered_functions.push_back({gpu_name,           value});
 #ifndef MANGOAPP
-    ordered_functions.push_back({vulkan_driver,      value});
-    ordered_functions.push_back({arch,               value});
-    ordered_functions.push_back({wine,               value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_vulkan_driver])
+        ordered_functions.push_back({vulkan_driver,      value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_arch])
+        ordered_functions.push_back({arch,               value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_wine])
+        ordered_functions.push_back({wine,               value});
 #endif
-    ordered_functions.push_back({frame_timing,       value});
-    ordered_functions.push_back({frame_count,         value});
-    ordered_functions.push_back({gamescope_frame_timing, value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_frame_timing])
+        ordered_functions.push_back({frame_timing,       value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_frame_count])
+        ordered_functions.push_back({frame_count,         value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_debug])
+        ordered_functions.push_back({gamescope_frame_timing, value});
 #ifndef MANGOAPP
-    ordered_functions.push_back({gamemode,           value});
-    ordered_functions.push_back({vkbasalt,           value});
-    ordered_functions.push_back({show_fps_limit,     value});
-    ordered_functions.push_back({resolution,         value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_gamemode])
+        ordered_functions.push_back({gamemode,           value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_vkbasalt])
+        ordered_functions.push_back({vkbasalt,           value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_show_fps_limit])
+        ordered_functions.push_back({show_fps_limit,     value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_resolution])
+        ordered_functions.push_back({resolution,         value});
 #endif
-    ordered_functions.push_back({gamepad_battery,    value});
-    ordered_functions.push_back({media_player,       value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_gamepad_battery])
+        ordered_functions.push_back({gamepad_battery,    value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_media_player])
+        ordered_functions.push_back({media_player,       value});
+    if (params->enabled[OVERLAY_PARAM_ENABLED_exec_name])
+        ordered_functions.push_back({exec_name,          value});
 }
 
 void HudElements::update_exec(){
