@@ -14,7 +14,7 @@ typedef unsigned long KeySym;
 Clock::time_point last_f2_press, toggle_fps_limit_press , last_f12_press, reload_cfg_press, last_upload_press;
 
 #if defined(HAVE_X11)
-bool keys_are_pressed(const std::vector<KeySym>& keys) {
+static inline bool keys_are_pressed(const std::vector<KeySym>& keys) {
 
     if (!init_x11())
         return false;
@@ -41,7 +41,7 @@ bool keys_are_pressed(const std::vector<KeySym>& keys) {
 }
 #elif defined(_WIN32)
 #include <windows.h>
-bool keys_are_pressed(const std::vector<KeySym>& keys) {
+static inline bool keys_are_pressed(const std::vector<KeySym>& keys) {
     size_t pressed = 0;
 
     for (KeySym ks : keys) {
@@ -56,7 +56,7 @@ bool keys_are_pressed(const std::vector<KeySym>& keys) {
     return false;
 }
 #else // XXX: Add wayland support
-bool keys_are_pressed(const std::vector<KeySym>& keys) {
+static inline bool keys_are_pressed(const std::vector<KeySym>& keys) {
     return false;
 }
 #endif
