@@ -15,7 +15,7 @@
 
 struct logData{
   double fps;
-  uint64_t frametime;
+  float frametime;
   float cpu_load;
   int gpu_load;
   int cpu_temp;
@@ -50,10 +50,12 @@ public:
   const std::vector<logData>& get_log_data() const noexcept { return m_log_array; }
   void clear_log_data() noexcept { m_log_array.clear(); }
 
+  void writeToFile();
+
   void upload_last_log();
   void upload_last_logs();
   void calculate_benchmark_data();
-  const std::string output_folder;
+  std::string output_folder;
   const int64_t log_interval;
   const int64_t log_duration;
 
@@ -74,7 +76,7 @@ extern std::unique_ptr<Logger> logger;
 extern std::string os, cpu, gpu, ram, kernel, driver, cpusched;
 extern bool sysInfoFetched;
 extern double fps;
-extern uint64_t frametime;
+extern float frametime;
 extern logData currentLogData;
 
 std::string exec(std::string command);
