@@ -33,10 +33,6 @@
 namespace fs = ghc::filesystem;
 using namespace std;
 
-#ifdef HAVE_DBUS
-float g_overflow = 50.f /* 3333ms * 0.5 / 16.6667 / 2 (to edge and back) */;
-#endif
-
 string gpuString,wineVersion,wineProcess;
 uint32_t deviceID;
 bool gui_open = false;
@@ -122,12 +118,15 @@ void update_hw_info(const struct overlay_params& params, uint32_t vendorID)
    if (params.enabled[OVERLAY_PARAM_ENABLED_gpu_stats] || logger->is_active()) {
       if (vendorID == 0x1002)
          getAmdGpuInfo();
-
+#ifdef __linux__
       if (gpu_metrics_exists)
          amdgpu_get_metrics();
-
+#endif
       if (vendorID == 0x10de)
          getNvidiaGpuInfo(params);
+
+      if (vendorID== 0x8086)
+         getIntelGpuInfo();
    }
 
 #ifdef __linux__
@@ -239,7 +238,8 @@ void update_hud_info_with_frametime(struct swapchain_stats& sw_stats, const stru
       frametime_data[f_idx] = frametime_ms;
    }
 
-   frametime = frametime_ns / 1000;
+   frametime = frametime_ms;
+   fps = double(1000 / frametime_ms);
 
    if (elapsed >= params.fps_sampling_period) {
       if (!hw_update_thread)
@@ -282,7 +282,8 @@ void update_hud_info_with_frametime(struct swapchain_stats& sw_stats, const stru
 void update_hud_info(struct swapchain_stats& sw_stats, const struct overlay_params& params, uint32_t vendorID){
    uint64_t now = os_time_get_nano(); /* ns */
    uint64_t frametime_ns = now - sw_stats.last_present_time;
-   update_hud_info_with_frametime(sw_stats, params, vendorID, frametime_ns);
+   if (!params.no_display || logger->is_active())
+      update_hud_info_with_frametime(sw_stats, params, vendorID, frametime_ns);
 }
 
 float get_time_stat(void *_data, int _idx)
@@ -304,11 +305,17 @@ void overlay_new_frame(const struct overlay_params& params)
    ImGui::PushStyleVar(ImGuiStyleVar_WindowBorderSize, 0.0f);
    ImGui::PushStyleVar(ImGuiStyleVar_ItemSpacing, ImVec2(8,-3));
    ImGui::PushStyleVar(ImGuiStyleVar_Alpha, params.alpha);
+   if (!params.enabled[OVERLAY_PARAM_ENABLED_hud_compact]){
+      ImGui::PushStyleVar(ImGuiStyleVar_WindowPadding, ImVec2(5,5));
+   }
+   else {
+      ImGui::PushStyleVar(ImGuiStyleVar_WindowPadding, ImVec2(0,0));
+   }
 }
 
 void overlay_end_frame()
 {
-   ImGui::PopStyleVar(3);
+   ImGui::PopStyleVar(4);
 }
 
 void position_layer(struct swapchain_stats& data, const struct overlay_params& params, const ImVec2& window_size)
@@ -316,7 +323,7 @@ void position_layer(struct swapchain_stats& data, const struct overlay_params& p
    unsigned width = ImGui::GetIO().DisplaySize.x;
    unsigned height = ImGui::GetIO().DisplaySize.y;
    float margin = 10.0f;
-   if (params.offset_x > 0 || params.offset_y > 0)
+   if (params.offset_x > 0 || params.offset_y > 0 || params.enabled[OVERLAY_PARAM_ENABLED_hud_no_margin])
       margin = 0.0f;
 
    ImGui::SetNextWindowBgAlpha(params.background_alpha);
@@ -350,6 +357,12 @@ void position_layer(struct swapchain_stats& data, const struct overlay_params& p
       data.main_window_pos = ImVec2((width / 2) - (window_size.x / 2), margin + params.offset_y);
       ImGui::SetNextWindowPos(data.main_window_pos, ImGuiCond_Always);
       break;
+   case LAYER_POSITION_BOTTOM_CENTER:
+      data.main_window_pos = ImVec2((width / 2) - (window_size.x / 2), height - window_size.y - margin + params.offset_y);
+      ImGui::SetNextWindowPos(data.main_window_pos, ImGuiCond_Always);
+      break;
+   case LAYER_POSITION_COUNT:
+      break;
    }
 }
 
@@ -363,10 +376,12 @@ void right_aligned_text(ImVec4& col, float off_x, const char *fmt, ...)
    vsnprintf(buffer, sizeof(buffer), fmt, args);
    va_end(args);
 
-   ImVec2 sz = ImGui::CalcTextSize(buffer);
-   ImGui::SetCursorPosX(pos.x + off_x - sz.x);
-   //ImGui::Text("%s", buffer);
-   ImGui::TextColored(col,"%s",buffer);
+   if (!HUDElements.params->enabled[OVERLAY_PARAM_ENABLED_hud_compact]){
+      ImVec2 sz = ImGui::CalcTextSize(buffer);
+      ImGui::SetCursorPosX(pos.x + off_x - sz.x);
+   }
+
+   ImGui::TextColored(col,"%s", buffer);
 }
 
 void center_text(const std::string& text)
@@ -374,7 +389,7 @@ void center_text(const std::string& text)
    ImGui::SetCursorPosX((ImGui::GetWindowSize().x / 2 )- (ImGui::CalcTextSize(text.c_str()).x / 2));
 }
 
-float get_ticker_limited_pos(float pos, float tw, float& left_limit, float& right_limit)
+static float get_ticker_limited_pos(float pos, float tw, float& left_limit, float& right_limit)
 {
    //float cw = ImGui::GetContentRegionAvailWidth() * 3; // only table cell worth of width
    float cw = ImGui::GetWindowContentRegionMax().x - ImGui::GetStyle().WindowPadding.x;
@@ -398,6 +413,8 @@ float get_ticker_limited_pos(float pos, float tw, float& left_limit, float& righ
 #ifdef HAVE_DBUS
 void render_mpris_metadata(const struct overlay_params& params, mutexed_metadata& meta, uint64_t frame_timing)
 {
+   static const float overflow = 50.f /* 3333ms * 0.5 / 16.6667 / 2 (to edge and back) */;
+
    if (meta.meta.valid) {
       auto color = ImGui::ColorConvertU32ToFloat4(params.media_player_color);
       ImGui::PushStyleVar(ImGuiStyleVar_ItemSpacing, ImVec2(8,0));
@@ -431,12 +448,12 @@ void render_mpris_metadata(const struct overlay_params& params, mutexed_metadata
       float new_pos, left_limit = 0, right_limit = 0;
       get_ticker_limited_pos(meta.ticker.pos, meta.ticker.longest, left_limit, right_limit);
 
-      if (meta.ticker.pos < left_limit - g_overflow * .5f) {
+      if (meta.ticker.pos < left_limit - overflow * .5f) {
          meta.ticker.dir = -1;
-         meta.ticker.pos = (left_limit - g_overflow * .5f) + 1.f /* random */;
-      } else if (meta.ticker.pos > right_limit + g_overflow) {
+         meta.ticker.pos = (left_limit - overflow * .5f) + 1.f /* random */;
+      } else if (meta.ticker.pos > right_limit + overflow) {
          meta.ticker.dir = 1;
-         meta.ticker.pos = (right_limit + g_overflow) - 1.f /* random */;
+         meta.ticker.pos = (right_limit + overflow) - 1.f /* random */;
       }
 
       meta.ticker.pos -= .5f * (frame_timing / 16666666.7f /* ns */) * meta.ticker.dir;
@@ -550,32 +567,54 @@ ImVec4 change_on_load_temp(LOAD_DATA& data, unsigned current)
    }
 }
 
+void horizontal_separator(struct overlay_params& params){
+   ImGui::SameLine();
+   ImGui::Spacing();
+   ImGui::SameLine();
+   ImGui::GetWindowDrawList()->AddLine(ImVec2(ImGui::GetCursorScreenPos().x - 5, ImGui::GetCursorScreenPos().y + 2), ImVec2(ImGui::GetCursorScreenPos().x - 5, ImGui::GetCursorScreenPos().y + params.font_size * 0.85), params.vram_color, 2);
+   ImGui::SameLine();
+   ImGui::Spacing();
+}
+
 void render_imgui(swapchain_stats& data, struct overlay_params& params, ImVec2& window_size, bool is_vulkan)
 {
+   // data.engine = EngineTypes::GAMESCOPE;
    HUDElements.sw_stats = &data; HUDElements.params = &params;
    HUDElements.is_vulkan = is_vulkan;
    ImGui::GetIO().FontGlobalScale = params.font_scale;
    static float ralign_width = 0, old_scale = 0;
+   auto io = ImGui::GetIO();
    if (params.enabled[OVERLAY_PARAM_ENABLED_fps_only]){
       window_size = ImVec2((to_string(int(HUDElements.sw_stats->fps)).length() * ImGui::CalcTextSize("A").x) + 15.f, params.height);
+   } else if (params.enabled[OVERLAY_PARAM_ENABLED_horizontal]) {
+      window_size = ImVec2(io.DisplaySize.x, params.height);
    } else {
       window_size = ImVec2(params.width, params.height);
    }
-   unsigned height = ImGui::GetIO().DisplaySize.y;
+   unsigned height = io.DisplaySize.y;
    auto now = Clock::now();
 
    if (old_scale != params.font_scale) {
       HUDElements.ralign_width = ralign_width = ImGui::CalcTextSize("A").x * 4 /* characters */;
       old_scale = params.font_scale;
    }
+   ImGuiTableFlags table_flags = ImGuiTableFlags_NoClip;
+   if(params.enabled[OVERLAY_PARAM_ENABLED_horizontal])
+      table_flags = ImGuiTableFlags_NoClip | ImGuiTableFlags_SizingFixedFit | ImGuiTableFlags_NoHostExtendX;
 
    if (!params.no_display && !steam_focused){
       ImGui::Begin("Main", &gui_open, ImGuiWindowFlags_NoDecoration);
-      if (ImGui::BeginTable("hud", params.table_columns, ImGuiTableFlags_NoClip)) {
+      if (ImGui::BeginTable("hud", params.table_columns, table_flags )) {
          HUDElements.place = 0;
          for (auto& func : HUDElements.ordered_functions){
+            ImGui::PushStyleVar(ImGuiStyleVar_CellPadding, ImVec2(-3,-3));
+            if(!params.enabled[OVERLAY_PARAM_ENABLED_horizontal])
+               ImGui::TableNextRow();
             func.first();
             HUDElements.place += 1;
+            ImGui::PopStyleVar();
+            if(!HUDElements.ordered_functions.empty() && params.enabled[OVERLAY_PARAM_ENABLED_horizontal] && func != HUDElements.ordered_functions.back())
+               horizontal_separator(params);
          }
          ImGui::EndTable();
       }
@@ -665,12 +704,10 @@ void init_gpu_stats(uint32_t& vendorID, uint32_t reported_deviceID, overlay_para
 
       if(checkNvidia(pci_dev))
          vendorID = 0x10de;
-      else
-         params.enabled[OVERLAY_PARAM_ENABLED_gpu_stats] = false;
    }
 
 #ifdef __linux__
-   if (vendorID == 0x8086 || vendorID == 0x1002
+   if (vendorID == 0x1002 || vendorID==0x8086
        || gpu.find("Radeon") != std::string::npos
        || gpu.find("AMD") != std::string::npos) {
       string path;
@@ -678,9 +715,12 @@ void init_gpu_stats(uint32_t& vendorID, uint32_t reported_deviceID, overlay_para
 
       auto dirs = ls(drm.c_str(), "card");
       for (auto& dir : dirs) {
+         if (dir.find("-") != std::string::npos) {
+             continue; // filter display adapters
+         }
          path = drm + dir;
 
-         SPDLOG_DEBUG("amdgpu path check: {}", path);
+         SPDLOG_DEBUG("drm path check: {}", path);
          if (pci_bus_parsed && pci_dev) {
             string pci_device = read_symlink((path + "/device").c_str());
             SPDLOG_DEBUG("PCI device symlink: '{}'", pci_device);
@@ -717,7 +757,7 @@ void init_gpu_stats(uint32_t& vendorID, uint32_t reported_deviceID, overlay_para
 
          const std::string device_path = path + "/device";
          const std::string gpu_metrics_path = device_path + "/gpu_metrics";
-         if (amdgpu_check_metrics(gpu_metrics_path)) {
+         if (amdgpu_verify_metrics(gpu_metrics_path)) {
             gpu_metrics_exists = true;
             metrics_path = gpu_metrics_path;
             SPDLOG_DEBUG("Using gpu_metrics of {}", gpu_metrics_path);
@@ -759,7 +799,7 @@ void init_gpu_stats(uint32_t& vendorID, uint32_t reported_deviceID, overlay_para
       }
 
       // don't bother then
-      if (metrics_path.empty() && !amdgpu.busy) {
+      if (metrics_path.empty() && !amdgpu.busy && vendorID != 0x8086) {
          params.enabled[OVERLAY_PARAM_ENABLED_gpu_stats] = false;
       }
    }
@@ -825,7 +865,10 @@ void init_system_info(){
          else {
             char *dir = dirname((char*)wineProcess.c_str());
             stringstream findVersion;
-            findVersion << "\"" << dir << "/wine\" --version";
+            if (preloader == "wine-preloader")
+               findVersion << "\"" << dir << "/wine\" --version";
+            else
+               findVersion << "\"" << dir << "/wine64\" --version";
             const char *wine_env = getenv("WINELOADERNOEXEC");
             if (wine_env)
                unsetenv("WINELOADERNOEXEC");
@@ -886,14 +929,18 @@ std::string get_device_name(uint32_t vendorID, uint32_t deviceID)
 
 void update_fan(){
    // This just handles steam deck fan for now
+   static bool init;
    string hwmon_path;
-   string path = "/sys/class/hwmon/";
-   auto dirs = ls(path.c_str(), "hwmon", LS_DIRS);
-   for (auto& dir : dirs) {
-      string full_path = (path + dir + "/name").c_str();
-      if (read_line(full_path).find("jupiter") != string::npos){
-         hwmon_path = path + dir + "/fan1_input";
-         break;
+
+   if (!init){
+      string path = "/sys/class/hwmon/";
+      auto dirs = ls(path.c_str(), "hwmon", LS_DIRS);
+      for (auto& dir : dirs) {
+         string full_path = (path + dir + "/name").c_str();
+         if (read_line(full_path).find("steamdeck_hwmon") != string::npos){
+            hwmon_path = path + dir + "/fan1_input";
+            break;
+         }
       }
    }
 
@@ -902,3 +949,11 @@ void update_fan(){
    else
       fan_speed = -1;
 }
+
+void next_hud_position(struct overlay_params& params){
+   if (params.position < (overlay_param_position::LAYER_POSITION_COUNT - 1)){
+      params.position = static_cast<overlay_param_position>(params.position + 1);
+   } else {
+      params.position = static_cast<overlay_param_position>(0);
+   }
+}
