@@ -1,3 +1,4 @@
+#include <cstdint>
 #ifdef _WIN32
 #include <windows.h>
 #endif
@@ -26,19 +27,16 @@
 #include "hud_elements.h"
 #include "blacklist.h"
 #include "mesa/util/os_socket.h"
+#include "file_utils.h"
 
 #ifdef HAVE_X11
 #include <X11/keysym.h>
 #include "loaders/loader_x11.h"
 #endif
 
-#ifdef HAVE_DBUS
 #include "dbus_info.h"
-#endif
 
-#ifdef MANGOAPP
 #include "app/mangoapp.h"
-#endif
 
 #if __cplusplus >= 201703L
 
@@ -144,20 +142,22 @@ parse_string_to_keysym_vec(const char *str)
    return keys;
 }
 
-#define parse_toggle_hud         parse_string_to_keysym_vec
-#define parse_toggle_logging     parse_string_to_keysym_vec
-#define parse_reload_cfg         parse_string_to_keysym_vec
-#define parse_upload_log         parse_string_to_keysym_vec
-#define parse_upload_logs        parse_string_to_keysym_vec
-#define parse_toggle_fps_limit   parse_string_to_keysym_vec
+#define parse_toggle_hud            parse_string_to_keysym_vec
+#define parse_toggle_hud_position   parse_string_to_keysym_vec
+#define parse_toggle_logging        parse_string_to_keysym_vec
+#define parse_reload_cfg            parse_string_to_keysym_vec
+#define parse_upload_log            parse_string_to_keysym_vec
+#define parse_upload_logs           parse_string_to_keysym_vec
+#define parse_toggle_fps_limit      parse_string_to_keysym_vec
 
 #else
-#define parse_toggle_hud(x)      {}
-#define parse_toggle_logging(x)  {}
-#define parse_reload_cfg(x)      {}
-#define parse_upload_log(x)      {}
-#define parse_upload_logs(x)     {}
-#define parse_toggle_fps_limit(x)    {}
+#define parse_toggle_hud(x)            {}
+#define parse_toggle_hud_position(x)   {}
+#define parse_toggle_logging(x)        {}
+#define parse_reload_cfg(x)            {}
+#define parse_upload_log(x)            {}
+#define parse_upload_logs(x)           {}
+#define parse_toggle_fps_limit(x)      {}
 #endif
 
 static uint32_t
@@ -189,6 +189,16 @@ parse_fps_limit(const char *str)
    return fps_limit;
 }
 
+static enum fps_limit_method
+parse_fps_limit_method(const char *str)
+{
+   if (!strcmp(str, "early")) {
+      return FPS_LIMIT_METHOD_EARLY;
+   }
+
+   return FPS_LIMIT_METHOD_LATE;
+}
+
 static bool
 parse_no_display(const char *str)
 {
@@ -410,6 +420,9 @@ parse_gl_size_query(const char *str)
 #define parse_round_corners(s) parse_unsigned(s)
 #define parse_fcat_overlay_width(s) parse_unsigned(s)
 #define parse_fcat_screen_edge(s) parse_unsigned(s)
+#define parse_picmip(s) parse_signed(s)
+#define parse_af(s) parse_signed(s)
+#define parse_preset(s) parse_signed(s)
 
 #define parse_cpu_color(s) parse_color(s)
 #define parse_gpu_color(s) parse_color(s)
@@ -515,7 +528,6 @@ parse_overlay_env(struct overlay_params *params,
    char key[256], value[256];
    while ((num = parse_string(env, key, value)) != 0) {
       env += num;
-      HUDElements.sort_elements({key, value});
       if (!strcmp("full", key)) {
          bool read_cfg = params->enabled[OVERLAY_PARAM_ENABLED_read_cfg];
 #define OVERLAY_PARAM_BOOL(name) \
@@ -536,16 +548,26 @@ parse_overlay_env(struct overlay_params *params,
          params->enabled[OVERLAY_PARAM_ENABLED_throttling_status] = 0;
          params->enabled[OVERLAY_PARAM_ENABLED_read_cfg] = read_cfg;
          params->enabled[OVERLAY_PARAM_ENABLED_fcat] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_horizontal] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_hud_no_margin] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_log_versioning] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_hud_compact] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_exec_name] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_trilinear] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_bicubic] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_retro] = 0;
       }
 #define OVERLAY_PARAM_BOOL(name)                                       \
       if (!strcmp(#name, key)) {                                       \
          params->enabled[OVERLAY_PARAM_ENABLED_##name] =               \
             strtol(value, NULL, 0);                                    \
+         add_to_options(params, key, value);                           \
          continue;                                                     \
       }
 #define OVERLAY_PARAM_CUSTOM(name)                                     \
       if (!strcmp(#name, key)) {                                       \
          params->name = parse_##name(value);                           \
+         add_to_options(params, key, value);                           \
          continue;                                                     \
       }
       OVERLAY_PARAMS
@@ -593,6 +615,7 @@ parse_overlay_config(struct overlay_params *params,
    params->height = 140;
    params->control = -1;
    params->fps_limit = { 0 };
+   params->fps_limit_method = FPS_LIMIT_METHOD_LATE;
    params->vsync = -1;
    params->gl_vsync = -2;
    params->offset_x = 0;
@@ -618,7 +641,7 @@ parse_overlay_config(struct overlay_params *params,
    params->gpu_load_color = { 0x39f900, 0xfdfd09, 0xb22222 };
    params->cpu_load_color = { 0x39f900, 0xfdfd09, 0xb22222 };
    params->font_scale_media_player = 0.55f;
-   params->log_interval = 100;
+   params->log_interval = 0;
    params->media_player_format = { "{title}", "{artist}", "{album}" };
    params->permit_upload = 0;
    params->benchmark_percentiles = { "97", "AVG"};
@@ -630,9 +653,13 @@ parse_overlay_config(struct overlay_params *params,
    params->round_corners = 0;
    params->battery_color =0xff9078;
    params->fsr_steam_sharpness = -1;
+   params->picmip = -17;
+   params->af = -1;
+   params->preset = -1;
 
 #ifdef HAVE_X11
    params->toggle_hud = { XK_Shift_R, XK_F12 };
+   params->toggle_hud_position = { XK_Shift_R, XK_F11 };
    params->toggle_fps_limit = { XK_Shift_L, XK_F1 };
    params->toggle_logging = { XK_Shift_L, XK_F2 };
    params->reload_cfg = { XK_Shift_L, XK_F4 };
@@ -668,6 +695,10 @@ parse_overlay_config(struct overlay_params *params,
 
       // Get config options
       parseConfigFile(*params);
+
+      if (params->options.find("preset") != params->options.end())
+         presets(stoi(params->options.find("preset")->second), params);
+
       if (params->options.find("full") != params->options.end() && params->options.find("full")->second != "0") {
 #define OVERLAY_PARAM_BOOL(name) \
             params->enabled[OVERLAY_PARAM_ENABLED_##name] = 1;
@@ -682,6 +713,14 @@ parse_overlay_config(struct overlay_params *params,
          params->enabled[OVERLAY_PARAM_ENABLED_hide_fsr_sharpness] = 0;
          params->enabled[OVERLAY_PARAM_ENABLED_throttling_status] = 0;
          params->enabled[OVERLAY_PARAM_ENABLED_fcat] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_horizontal] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_hud_no_margin] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_log_versioning] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_hud_compact] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_exec_name] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_trilinear] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_bicubic] = 0;
+         params->enabled[OVERLAY_PARAM_ENABLED_retro] = 0;
          params->options.erase("full");
       }
       for (auto& it : params->options) {
@@ -765,8 +804,8 @@ parse_overlay_config(struct overlay_params *params,
    }
 
    //increase hud width if io read and write
-   if (!params->width) {
-      params->width = params->font_size * params->font_scale * params->table_columns * 4;
+   if (!params->width && !params->enabled[OVERLAY_PARAM_ENABLED_horizontal]) {
+      params->width = params->font_size * params->font_scale * params->table_columns * 4.6;
 
       if ((params->enabled[OVERLAY_PARAM_ENABLED_io_read] || params->enabled[OVERLAY_PARAM_ENABLED_io_write])) {
          params->width += 2 * params->font_size * params->font_scale;
@@ -792,6 +831,8 @@ parse_overlay_config(struct overlay_params *params,
    else
       fps_limit_stats.targetFrameTime = {};
 
+   fps_limit_stats.method = params->fps_limit_method;
+
 #ifdef HAVE_DBUS
    if (params->enabled[OVERLAY_PARAM_ENABLED_media_player]) {
       if (dbusmgr::dbus_mgr.init(dbusmgr::SRV_MPRIS))
@@ -817,9 +858,6 @@ parse_overlay_config(struct overlay_params *params,
 
    auto real_size = params->font_size * params->font_scale;
    real_font_size = ImVec2(real_size, real_size / 2);
-#ifdef MANGOAPP
-   params->log_interval = 0;
-#endif
    HUDElements.params = params;
    if (params->enabled[OVERLAY_PARAM_ENABLED_legacy_layout]){
         HUDElements.legacy_elements();
@@ -853,3 +891,107 @@ parse_overlay_config(struct overlay_params *params,
    g_fsrSharpness = params->fsr_steam_sharpness;
 #endif
 }
+
+bool parse_preset_config(int preset, struct overlay_params *params){
+   const std::string data_dir = get_data_dir();
+   const std::string config_dir = get_config_dir();
+   std::string preset_path = config_dir + "/MangoHud/" + "presets.conf";
+   FILE *preset_file = fopen(preset_path.c_str(), "r");
+   char line[20];
+   char preset_string[20];
+   sprintf(preset_string, "[preset %d]\n", preset);
+   bool found_preset = false;
+   if (preset_file == NULL)
+      return false;
+
+   while (fgets(line, sizeof(line), preset_file)){
+      if (strcmp(line, preset_string) == 0){
+         found_preset = true;
+         continue;
+      }
+
+      if (found_preset){
+         if(strcmp(line, "preset") == 0 || line[0] == '\n' || line[0] == '\0')
+            break;
+
+         parseConfigLine(line, params->options);
+      }
+   }
+
+   fclose(preset_file);
+   return found_preset;
+}
+
+void add_to_options(struct overlay_params *params, std::string option, std::string value){
+   HUDElements.options.push_back({option, value});
+   params->options[option] = value;
+}
+
+void presets(int preset, struct overlay_params *params) {
+   if (parse_preset_config(preset, params))
+      return;
+
+   switch(preset) {
+      case 0:
+         params->no_display = 1;
+         break;
+
+      case 1:
+         params->width = 40;
+         add_to_options(params, "legacy_layout", "0");
+         add_to_options(params, "cpu_stats", "0");
+         add_to_options(params, "gpu_stats", "0");
+         add_to_options(params, "fps", "1");
+         add_to_options(params, "fps_only", "1");
+         add_to_options(params, "frametime", "0");
+         break;
+      
+      case 2:
+         params->table_columns = 20;
+         add_to_options(params, "horizontal", "1");
+         add_to_options(params, "legacy_layout", "0");
+         add_to_options(params, "fps", "1");
+         add_to_options(params, "table_columns", "20");
+         add_to_options(params, "frame_timing", "1");
+         add_to_options(params, "frametime", "0");
+         add_to_options(params, "cpu_stats", "1");
+         add_to_options(params, "gpu_stats", "1");
+         add_to_options(params, "ram", "1");
+         add_to_options(params, "vram", "1");
+         add_to_options(params, "battery", "1");
+         add_to_options(params, "hud_no_margin", "1");
+         add_to_options(params, "gpu_power", "1");
+         add_to_options(params, "cpu_power", "1");
+         add_to_options(params, "battery_watt", "1");
+         add_to_options(params, "battery_time", "1");
+         break;
+      
+      case 3:
+         add_to_options(params, "cpu_temp", "1");
+         add_to_options(params, "gpu_temp", "1");
+         add_to_options(params, "ram", "1");
+         add_to_options(params, "vram", "1");
+         add_to_options(params, "cpu_power", "1");
+         add_to_options(params, "gpu_power", "1");
+         add_to_options(params, "cpu_mhz", "1");
+         add_to_options(params, "gpu_mem_clock", "1");
+         add_to_options(params, "gpu_core_clock", "1");
+         add_to_options(params, "battery", "1");
+         break;
+
+      case 4:
+         add_to_options(params, "full", "1");
+         add_to_options(params, "io_read", "0");
+         add_to_options(params, "io_write", "0");
+         add_to_options(params, "arch", "0");
+         add_to_options(params, "engine_version", "0");
+         add_to_options(params, "battery", "1");
+         add_to_options(params, "gamemode", "0");
+         add_to_options(params, "vkbasalt", "0");
+         add_to_options(params, "frame_count", "0");
+         add_to_options(params, "show_fps_limit", "0");
+         add_to_options(params, "resolution", "0");
+         break;
+
+   }
+}
