@@ -85,6 +85,15 @@ typedef unsigned long KeySym;
    OVERLAY_PARAM_BOOL(throttling_status)             \
    OVERLAY_PARAM_BOOL(fcat)                          \
    OVERLAY_PARAM_BOOL(log_versioning)                \
+   OVERLAY_PARAM_BOOL(horizontal)                    \
+   OVERLAY_PARAM_BOOL(hud_no_margin)                 \
+   OVERLAY_PARAM_BOOL(hud_compact)                   \
+   OVERLAY_PARAM_BOOL(battery_watt)                  \
+   OVERLAY_PARAM_BOOL(battery_time)                  \
+   OVERLAY_PARAM_BOOL(exec_name)                     \
+   OVERLAY_PARAM_BOOL(trilinear)                     \
+   OVERLAY_PARAM_BOOL(bicubic)                       \
+   OVERLAY_PARAM_BOOL(retro)                         \
    OVERLAY_PARAM_CUSTOM(fps_sampling_period)         \
    OVERLAY_PARAM_CUSTOM(output_folder)               \
    OVERLAY_PARAM_CUSTOM(output_file)                 \
@@ -102,12 +111,14 @@ typedef unsigned long KeySym;
    OVERLAY_PARAM_CUSTOM(no_display)                  \
    OVERLAY_PARAM_CUSTOM(control)                     \
    OVERLAY_PARAM_CUSTOM(fps_limit)                   \
+   OVERLAY_PARAM_CUSTOM(fps_limit_method)            \
    OVERLAY_PARAM_CUSTOM(vsync)                       \
    OVERLAY_PARAM_CUSTOM(gl_vsync)                    \
    OVERLAY_PARAM_CUSTOM(gl_size_query)               \
    OVERLAY_PARAM_CUSTOM(gl_bind_framebuffer)         \
    OVERLAY_PARAM_CUSTOM(gl_dont_flip)                \
    OVERLAY_PARAM_CUSTOM(toggle_hud)                  \
+   OVERLAY_PARAM_CUSTOM(toggle_hud_position)         \
    OVERLAY_PARAM_CUSTOM(toggle_fps_limit)            \
    OVERLAY_PARAM_CUSTOM(toggle_logging)              \
    OVERLAY_PARAM_CUSTOM(reload_cfg)                  \
@@ -156,15 +167,21 @@ typedef unsigned long KeySym;
    OVERLAY_PARAM_CUSTOM(fsr_steam_sharpness)         \
    OVERLAY_PARAM_CUSTOM(fcat_screen_edge)            \
    OVERLAY_PARAM_CUSTOM(fcat_overlay_width)          \
+   OVERLAY_PARAM_CUSTOM(picmip)                      \
+   OVERLAY_PARAM_CUSTOM(af)                          \
+   OVERLAY_PARAM_CUSTOM(preset)                      \
 
 enum overlay_param_position {
    LAYER_POSITION_TOP_LEFT,
+   LAYER_POSITION_TOP_CENTER,
    LAYER_POSITION_TOP_RIGHT,
    LAYER_POSITION_MIDDLE_LEFT,
    LAYER_POSITION_MIDDLE_RIGHT,
    LAYER_POSITION_BOTTOM_LEFT,
+   LAYER_POSITION_BOTTOM_CENTER,
    LAYER_POSITION_BOTTOM_RIGHT,
-   LAYER_POSITION_TOP_CENTER,
+   // Count must always be the last entry
+   LAYER_POSITION_COUNT,
 };
 
 enum overlay_plots {
@@ -190,6 +207,11 @@ enum gl_size_query {
    GL_SIZE_SCISSORBOX, // needed?
 };
 
+enum fps_limit_method {
+   FPS_LIMIT_METHOD_EARLY,
+   FPS_LIMIT_METHOD_LATE
+};
+
 enum overlay_param_enabled {
 #define OVERLAY_PARAM_BOOL(name) OVERLAY_PARAM_ENABLED_##name,
 #define OVERLAY_PARAM_CUSTOM(name)
@@ -205,6 +227,7 @@ struct overlay_params {
    int control;
    uint32_t fps_sampling_period; /* ns */
    std::vector<std::uint32_t> fps_limit;
+   enum fps_limit_method fps_limit_method;
    bool help;
    bool no_display;
    bool full;
@@ -240,6 +263,7 @@ struct overlay_params {
    std::vector<KeySym> reload_cfg;
    std::vector<KeySym> upload_log;
    std::vector<KeySym> upload_logs;
+   std::vector<KeySym> toggle_hud_position;
    std::string time_format, output_folder, output_file;
    std::string pci_dev;
    std::string media_player_name;
@@ -258,7 +282,9 @@ struct overlay_params {
    int fsr_steam_sharpness;
    unsigned short fcat_screen_edge;
    unsigned short fcat_overlay_width;
-
+   int picmip;
+   int af;
+   int preset;
    size_t font_params_hash;
 };
 
@@ -266,6 +292,9 @@ const extern char *overlay_param_names[];
 
 void parse_overlay_config(struct overlay_params *params,
                        const char *env);
+void presets(int preset, struct overlay_params *params);
+bool parse_preset_config(int preset, struct overlay_params *params);
+void add_to_options(struct overlay_params *params, std::string option, std::string value);
 
 #ifdef __cplusplus
 }
