@@ -34,6 +34,7 @@
 #include <list>
 #include <array>
 #include <iomanip>
+#include <sstream>
 #include <inttypes.h>
 #include <spdlog/spdlog.h>
 #include <imgui.h>
@@ -400,7 +401,7 @@ static void destroy_swapchain_data(struct swapchain_data *data)
    delete data;
 }
 
-struct overlay_draw *get_overlay_draw(struct swapchain_data *data)
+static struct overlay_draw *get_overlay_draw(struct swapchain_data *data)
 {
    struct device_data *device_data = data->device;
    struct overlay_draw *draw = data->draws.empty() ?
@@ -1574,6 +1575,13 @@ static VkResult overlay_QueuePresentKHR(
     VkQueue                                     queue,
     const VkPresentInfoKHR*                     pPresentInfo)
 {
+   using namespace std::chrono_literals;
+   if (fps_limit_stats.targetFrameTime > 0s && fps_limit_stats.method == FPS_LIMIT_METHOD_EARLY){
+      fps_limit_stats.frameStart = Clock::now();
+      FpsLimiter(fps_limit_stats);
+      fps_limit_stats.frameEnd = Clock::now();
+   }
+
    struct queue_data *queue_data = FIND(struct queue_data, queue);
 
    /* Otherwise we need to add our overlay drawing semaphore to the list of
@@ -1616,9 +1624,7 @@ static VkResult overlay_QueuePresentKHR(
          result = chain_result;
    }
 
-   using namespace std::chrono_literals;
-
-   if (fps_limit_stats.targetFrameTime > 0s){
+   if (fps_limit_stats.targetFrameTime > 0s && fps_limit_stats.method == FPS_LIMIT_METHOD_LATE){
       fps_limit_stats.frameStart = Clock::now();
       FpsLimiter(fps_limit_stats);
       fps_limit_stats.frameEnd = Clock::now();
@@ -1749,12 +1755,10 @@ static VkResult overlay_CreateDevice(
    // Advance the link info for the next element on the chain
    chain_info->u.pLayerInfo = chain_info->u.pLayerInfo->pNext;
 
-   VkPhysicalDeviceFeatures device_features = {};
-   VkDeviceCreateInfo device_info = *pCreateInfo;
 
-   std::vector<const char*> enabled_extensions(device_info.ppEnabledExtensionNames,
-                                               device_info.ppEnabledExtensionNames +
-                                               device_info.enabledExtensionCount);
+   std::vector<const char*> enabled_extensions(pCreateInfo->ppEnabledExtensionNames,
+                                               pCreateInfo->ppEnabledExtensionNames +
+                                               pCreateInfo->enabledExtensionCount);
 
    uint32_t extension_count;
    instance_data->vtable.EnumerateDeviceExtensionProperties(physicalDevice, nullptr, &extension_count, nullptr);
@@ -1782,15 +1786,7 @@ static VkResult overlay_CreateDevice(
       FOUND:;
    }
 
-   device_info.enabledExtensionCount = enabled_extensions.size();
-   device_info.ppEnabledExtensionNames = enabled_extensions.data();
-
-   if (pCreateInfo->pEnabledFeatures)
-      device_features = *(pCreateInfo->pEnabledFeatures);
-   device_info.pEnabledFeatures = &device_features;
-
-
-   VkResult result = fpCreateDevice(physicalDevice, &device_info, pAllocator, pDevice);
+   VkResult result = fpCreateDevice(physicalDevice, pCreateInfo, pAllocator, pDevice);
    if (result != VK_SUCCESS) return result;
 
    struct device_data *device_data = new_device_data(*pDevice, instance_data);
@@ -1936,6 +1932,48 @@ static VkResult overlay_CreateInstance(
    return result;
 }
 
+static VkResult overlay_CreateSampler(
+	VkDevice                     device,
+	const VkSamplerCreateInfo*   pCreateInfo,
+	const VkAllocationCallbacks* pAllocator,
+	VkSampler*                   pSampler)
+{
+   struct device_data *device_data = FIND(struct device_data, device);
+   auto params = device_data->instance->params;
+	VkSamplerCreateInfo sampler = *pCreateInfo;
+
+   if (params.picmip > -17 && params.picmip < 17)
+      sampler.mipLodBias = params.picmip;
+
+   if (params.af > 0){
+      sampler.anisotropyEnable = VK_TRUE;
+      sampler.maxAnisotropy = params.af;
+   } else if (params.af == 0)
+      sampler.anisotropyEnable = VK_FALSE;
+
+   if (params.enabled[OVERLAY_PARAM_ENABLED_trilinear]){
+      sampler.magFilter = VK_FILTER_LINEAR;
+      sampler.minFilter = VK_FILTER_LINEAR;
+      sampler.mipmapMode = VK_SAMPLER_MIPMAP_MODE_LINEAR;
+   }
+
+   if (params.enabled[OVERLAY_PARAM_ENABLED_bicubic]){
+      sampler.magFilter = VK_FILTER_CUBIC_IMG;
+      sampler.minFilter = VK_FILTER_CUBIC_IMG;
+      sampler.mipmapMode = VK_SAMPLER_MIPMAP_MODE_LINEAR;
+   }
+
+   if (params.enabled[OVERLAY_PARAM_ENABLED_retro]){
+      sampler.magFilter = VK_FILTER_NEAREST;
+      sampler.minFilter = VK_FILTER_NEAREST;
+      sampler.mipmapMode = VK_SAMPLER_MIPMAP_MODE_NEAREST;
+   }
+
+	VkResult result = device_data->vtable.CreateSampler(device, &sampler, pAllocator, pSampler);
+
+	return result;
+}
+
 static void overlay_DestroyInstance(
     VkInstance                                  instance,
     const VkAllocationCallbacks*                pAllocator)
@@ -1973,6 +2011,7 @@ static const struct {
    ADD_HOOK(CreateSwapchainKHR),
    ADD_HOOK(QueuePresentKHR),
    ADD_HOOK(DestroySwapchainKHR),
+   ADD_HOOK(CreateSampler),
 
    ADD_HOOK(QueueSubmit),
 
