@@ -1,10 +1,11 @@
+#pragma once
 #include <dxgi.h>
 #include <dxgi1_5.h>
 #include <dxgi1_4.h>
 #ifdef _MSC_VER
     #include <d3d12.h>
 #else
-    #include "/usr/include/wine/windows/d3d12.h"
+    #include "/usr/i686-w64-mingw32/include/d3d12.h"
 #endif
 #ifndef __D3D12_IMPL_H__
 #define __D3D12_IMPL_H__
@@ -16,6 +17,6 @@ namespace impl
 		void init();
 	}
 }
-
+long __fastcall hkPresent12(IDXGISwapChain3* pSwapChain, UINT SyncInterval, UINT Flags);
 
 #endif // __D3D12_IMPL_H__
\ No newline at end of file
